@@ -8,7 +8,6 @@
 """
 from bson.objectid import ObjectId
 from pymongo import UpdateOne
-from urllib import parse
 import showlog
 import pymongo
 import time
@@ -302,7 +301,7 @@ class Basics:
         按照查询语句查找，内置将查询结果提取到list里面
         my_query = {'_id': 'balabala'}
         show_setting = {'_id': 0}  不显示_id，显示就为1，注意为dict格式，最好新建dict
-        sort_setting = {'age': 1} 1正序 -1倒序，参照：https://www.cnblogs.com/songzhixue/p/11203534.html
+        sort_setting = {'age': 1} 1正序 -1倒序
         query={} 表示查询所有数据
         """
         if db is None:
